Density and random variate generation for symmetric probability distributions in the rotations package
The functions for the density function and random variate generation are named in the usual form dxxxx and rxxxx respectively.
See dcayley
for the Cayley distribution.
See
dfisherfor the matrix Fisher distribution.
See dhaar for the uniform
distribution on the circle.
See
dvmises for the von Mises-Fisher
distribution.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.