Fisher: The Matrix Fisher Distribution

Description Usage Arguments Details Value See Also

Description

Density and random generation for the matrix Fisher distribution with concentration kappa (κ)

Usage

1
2
3
4
5
  dfisher(r, kappa = 1, nu = NULL, Haar = TRUE)

  pfisher(q, kappa = 1, nu = NULL, lower.tail = TRUE)

  rfisher(n, kappa = 1, nu = NULL)

Arguments

r,q

vector of quantiles

n

number of observations. If length(n)>1, the length is taken to be the number required

kappa

concentration paramter

nu

circular variance, can be used in place of kappa

Haar

logical; if TRUE density is evaluated with respect to Haar

Details

The matrix Fisher distribution with concentration kappa (or circular variance nu) has density

C(r|κ)=exp[2κ cos(r)][1-cos(r)]/(2π[I0(2κ)-I1(2κ)])

where Ip() denotes the Bessel function of order p defined as Ip(κ) is the modified Bessel function with parameters p and kappa.

Value

dfisher gives the density, pfisher gives the distribution function, rfisher generates random deviates

See Also

Angular-distributions for other distributions in the rotations package


heike/rotations documentation built on May 17, 2019, 3:24 p.m.