Description Usage Arguments Value See Also
A function to determine if a given matrix is in unit quaternion or not.
1 | is.Q4(x)
|
x |
numeric 1-by-4 vector of length 9 |
logical T if the vector is a unit quaternion and false otherwise
Other SO3: as.SO3, id.SO3,
is.SO3, SO3,
SO3-class, SO3.default,
SO3.Q4
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.