zhangCR: Zhang CR Method

Description Usage Arguments Value Examples

Description

Find the radius of a 100α% confidence region for the projected mean

Usage

1
2
3
4
5
6
7
8
9
  zhangCR(Qs, a, m, pivot, estimator)

  ## S3 method for class 'SO3'
 zhangCR(Rs, a, m = 300, pivot = T,
    estimator = "mean")

  ## S3 method for class 'Q4'
 zhangCR(Qs, alpha, m = 300, pivot = T,
    estimator = "mean")

Arguments

Rs,Qs

A n-by-p matrix where each row corresponds to a random rotation in matrix (p=9) or quaternion form (p=4)

a

The alpha level desired, e.g. 0.05 or 0.10

m

Number of replicates to use to estiamte cut point

pivot

should the pivotal (T) or non-pivotal (F) method be used

estimator

Mean or median

Value

radius of the confidence region centered at the projected mean

Examples

1
2
Rs<-ruars(20,rcayley,kappa=100)
region(Rs,method='zhang',alpha=0.9)

heike/rotations documentation built on May 17, 2019, 3:24 p.m.