Description Usage Arguments Details Value See Also
Density and random generation for the matrix Fisher distribution with concentration kappa (κ)
1 2 3 4 5 |
r,q |
vector of quantiles |
n |
number of observations. If |
kappa |
concentration paramter |
nu |
circular variance, can be used in place of kappa |
Haar |
logical; if TRUE density is evaluated with respect to Haar |
The matrix Fisher distribution with concentration kappa (or circular variance nu) has density
C(r|κ)=exp[2κ cos(r)][1-cos(r)]/(2π[I0(2κ)-I1(2κ)])
where Ip() denotes the Bessel function of order p defined as Ip(κ) is the modified Bessel function with parameters p and kappa.
dfisher gives the density, pfisher gives
the distribution function, rfisher generates
random deviates
Angular-distributions for other distributions in the rotations package
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.