Description Usage Arguments Value Examples
Find the radius of a 100α% confidence region for the projected mean
1 2 3 4 5 6 7 8 9 |
Rs,Qs |
A n-by-p matrix where each row corresponds to a random rotation in matrix (p=9) or quaternion form (p=4) |
a |
The alpha level desired, e.g. 0.05 or 0.10 |
m |
Number of replicates to use to estiamte cut point |
pivot |
should the pivotal (T) or non-pivotal (F) method be used |
estimator |
Mean or median |
radius of the confidence region centered at the projected mean
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.